{% extends "admin/login.html" %}

{% block content %}
    {{  block.super }}
    <br>
    <div style="text-align: center;">
        <a class="button" style="display: inline-block; margin-top: 20px" href="{% url 'start_oidc_auth' %}">NeoID Login</a>
    </div>
{% endblock %}
